@@ -4,14 +4,14 @@
 # 2021 MATLAB implementation by V. Angelidakis <v.angelidakis@qub.ac>
 # 2024 Translated from MATLAB to Python by U.A. Canbolat <utku.canbolat@fau.de>
 
-import sys
 
 from CLUMP import GenerateClump_Euclidean_3D
 import sys
+import os
 sys.path.append('../../')
 
 # Load particle shape from stl file
-inputGeom = 'ParticleGeometries/Hexahedron.stl'
+inputGeom = os.path.join(os.path.dirname(__file__), 'ParticleGeometries/Hexahedron.stl')
 N = 21
 rMin = 0
 div = 102
@@ -20,6 +20,6 @@ output = 'EU_Hexahedron.txt'
 outputVTK = 'EU_Hexahedron.vtk'
 visualise = True
 
-mesh,clump = GenerateClump_Euclidean_3D(inputGeom=inputGeom, N=N, rMin=rMin, div=div, overlap=overlap, output=output, outputVTK=outputVTK, visualise=visualise)
+mesh, clump = GenerateClump_Euclidean_3D(inputGeom=inputGeom, N=N, rMin=rMin, div=div, overlap=overlap, output=output, outputVTK=outputVTK, visualise=visualise)
 
-print('Total number of spheres: '+ str(clump.numSpheres))
+print('Total number of spheres: ' + str(clump.numSpheres))
