@@ -4,14 +4,14 @@
 # 2021 MATLAB implementation by V. Angelidakis <v.angelidakis@qub.ac>
 # 2024 Translated from MATLAB to Python by U.A. Canbolat <utku.canbolat@fau.de>
 
-import sys
 
 from CLUMP import GenerateClump_Euclidean_3D
 import sys
+import os
 sys.path.append('../../')
 
 # Load particle shape from stl file
-inputGeom = 'ParticleGeometries/Human_femur.stl'
+inputGeom = os.path.join(os.path.dirname(__file__), 'ParticleGeometries/Human_femur.stl')
 N = 200
 rMin = 0
 div = 102
@@ -19,8 +19,8 @@ overlap = 0.0
 output = 'EU_Human_femur.txt'
 outputVTK = 'EU_Human_femur.vtk'
 visualise = True
-rMax_ratio = 0.3 # Parameter to trigger the Extended Euclidean method
+rMax_ratio = 0.3  # Parameter to trigger the Extended Euclidean method
 
 mesh,clump = GenerateClump_Euclidean_3D(inputGeom=inputGeom, N=N, rMin=rMin, div=div, overlap=overlap, output=output, outputVTK=outputVTK, visualise=visualise, rMax_ratio=rMax_ratio)
 
-print('Total number of spheres: '+ str(clump.numSpheres))
+print('Total number of spheres: ' + str(clump.numSpheres))
