@@ -4,13 +4,12 @@
 # 2021 MATLAB implementation by V. Angelidakis <v.angelidakis@qub.ac>
 # 2024 Translated from MATLAB to Python by U.A. Canbolat <utku.canbolat@fau.de>
 
-import sys
-
 from CLUMP import GenerateClump_Favier
 import sys
+import os
 sys.path.append('../../')
 
-inputGeom = 'ParticleGeometries/Ellipsoid_R_2.0_1.0_1.0.stl'
+inputGeom = os.path.join(os.path.dirname(__file__), 'ParticleGeometries/Ellipsoid_R_2.0_1.0_1.0.stl')
 N = 10
 chooseDistance = 'min'
 output = 'FA_Ellipsoid_2.0_1.0_1.0.txt'
